

NIRISS
==============

.. currentmodule:: webbpsf

.. autoclass:: NIRISS
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~NIRISS.LONG_WAVELENGTH_MAX
      ~NIRISS.LONG_WAVELENGTH_MIN
      ~NIRISS.SHORT_WAVELENGTH_MAX
      ~NIRISS.SHORT_WAVELENGTH_MIN

   
   

   
   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: LONG_WAVELENGTH_MAX
   .. autoattribute:: LONG_WAVELENGTH_MIN
   .. autoattribute:: SHORT_WAVELENGTH_MAX
   .. autoattribute:: SHORT_WAVELENGTH_MIN

   
   

   
   
   